summaryrefslogtreecommitdiff
path: root/sw/source/core/text/portxt.cxx
diff options
context:
space:
mode:
authorFrank Meies <fme@openoffice.org>2002-02-07 10:20:40 +0000
committerFrank Meies <fme@openoffice.org>2002-02-07 10:20:40 +0000
commit9cbc4322e8308f2b71b89f9e6166ac673dd600a2 (patch)
tree3d75f1d361fc216525cd0be455c99d8331c875a7 /sw/source/core/text/portxt.cxx
parent6cb7868ddee66b6ade6fe8078521b540dead4b73 (diff)
#96678# new paragraph snap to grid attribute
Diffstat (limited to 'sw/source/core/text/portxt.cxx')
-rw-r--r--sw/source/core/text/portxt.cxx9
1 files changed, 5 insertions, 4 deletions
diff --git a/sw/source/core/text/portxt.cxx b/sw/source/core/text/portxt.cxx
index ac9f599cd429..9f23d4f294bb 100644
--- a/sw/source/core/text/portxt.cxx
+++ b/sw/source/core/text/portxt.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: portxt.cxx,v $
*
- * $Revision: 1.17 $
+ * $Revision: 1.18 $
*
- * last change: $Author: fme $ $Date: 2001-12-12 12:43:38 $
+ * last change: $Author: fme $ $Date: 2002-02-07 11:18:13 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -145,8 +145,9 @@ sal_Bool lcl_AddSpace( const SwTxtSizeInfo &rInf, const XubString& rStr,
else if ( pBreakIt->xBreak.is() )
nScript = (BYTE)pBreakIt->xBreak->getScriptType( rStr, nPos );
- // this character is ASIAN?
- if( ASIAN == nScript )
+ // this character is ASIAN, not KOREAN?
+ if( ASIAN == nScript &&
+ LANGUAGE_KOREAN != rInf.GetTxtFrm()->GetTxtNode()->GetLang( nPos ) )
return sal_True;
if ( ! i )